/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.blogger.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Post.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Blogger API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Post extends GenericJson {

  /**
   * The author of this Post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Author author;

  /**
   * Data about the blog containing this Post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Blog blog;

  /**
   * The content of the Post. May contain HTML markup.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String content;

  /**
   * The JSON meta-data for the Post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String customMetaData;

  /**
   * The identifier of this Post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of this entity. Always blogger#post
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The list of labels this Post was tagged with.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> labels;

  /**
   * The location for geotagged posts.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Location location;

  /**
   * RFC 3339 date-time when this Post was published.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime published;

  /**
   * The container of comments on this Post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Replies replies;

  /**
   * The API REST URL to fetch this resource from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * The title of the Post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * RFC 3339 date-time when this Post was last updated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * The URL where this Post is displayed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String url;

  /**
   * The author of this Post.
   * The value returned may be {@code null}.
   */
  public Author getAuthor() {
    return author;
  }

  /**
   * The author of this Post.
   * The value set may be {@code null}.
   */
  public Post setAuthor(Author author) {
    this.author = author;
    return this;
  }

  /**
   * Data about the blog containing this Post.
   * The value returned may be {@code null}.
   */
  public Blog getBlog() {
    return blog;
  }

  /**
   * Data about the blog containing this Post.
   * The value set may be {@code null}.
   */
  public Post setBlog(Blog blog) {
    this.blog = blog;
    return this;
  }

  /**
   * The content of the Post. May contain HTML markup.
   * The value returned may be {@code null}.
   */
  public String getContent() {
    return content;
  }

  /**
   * The content of the Post. May contain HTML markup.
   * The value set may be {@code null}.
   */
  public Post setContent(String content) {
    this.content = content;
    return this;
  }

  /**
   * The JSON meta-data for the Post.
   * The value returned may be {@code null}.
   */
  public String getCustomMetaData() {
    return customMetaData;
  }

  /**
   * The JSON meta-data for the Post.
   * The value set may be {@code null}.
   */
  public Post setCustomMetaData(String customMetaData) {
    this.customMetaData = customMetaData;
    return this;
  }

  /**
   * The identifier of this Post.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The identifier of this Post.
   * The value set may be {@code null}.
   */
  public Post setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of this entity. Always blogger#post
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of this entity. Always blogger#post
   * The value set may be {@code null}.
   */
  public Post setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The list of labels this Post was tagged with.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getLabels() {
    return labels;
  }

  /**
   * The list of labels this Post was tagged with.
   * The value set may be {@code null}.
   */
  public Post setLabels(java.util.List<String> labels) {
    this.labels = labels;
    return this;
  }

  /**
   * The location for geotagged posts.
   * The value returned may be {@code null}.
   */
  public Location getLocation() {
    return location;
  }

  /**
   * The location for geotagged posts.
   * The value set may be {@code null}.
   */
  public Post setLocation(Location location) {
    this.location = location;
    return this;
  }

  /**
   * RFC 3339 date-time when this Post was published.
   * The value returned may be {@code null}.
   */
  public DateTime getPublished() {
    return published;
  }

  /**
   * RFC 3339 date-time when this Post was published.
   * The value set may be {@code null}.
   */
  public Post setPublished(DateTime published) {
    this.published = published;
    return this;
  }

  /**
   * The container of comments on this Post.
   * The value returned may be {@code null}.
   */
  public Replies getReplies() {
    return replies;
  }

  /**
   * The container of comments on this Post.
   * The value set may be {@code null}.
   */
  public Post setReplies(Replies replies) {
    this.replies = replies;
    return this;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value set may be {@code null}.
   */
  public Post setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * The title of the Post.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of the Post.
   * The value set may be {@code null}.
   */
  public Post setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * RFC 3339 date-time when this Post was last updated.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * RFC 3339 date-time when this Post was last updated.
   * The value set may be {@code null}.
   */
  public Post setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * The URL where this Post is displayed.
   * The value returned may be {@code null}.
   */
  public String getUrl() {
    return url;
  }

  /**
   * The URL where this Post is displayed.
   * The value set may be {@code null}.
   */
  public Post setUrl(String url) {
    this.url = url;
    return this;
  }

  /**
   * The author of this Post.
   */
  public static final class Author extends GenericJson {

    /**
     * The display name.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String displayName;

    /**
     * The identifier of the Post creator.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The Post author's avatar.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Image image;

    /**
     * The URL of the Post creator's Profile page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * The display name.
     * The value returned may be {@code null}.
     */
    public String getDisplayName() {
      return displayName;
    }

    /**
     * The display name.
     * The value set may be {@code null}.
     */
    public Author setDisplayName(String displayName) {
      this.displayName = displayName;
      return this;
    }

    /**
     * The identifier of the Post creator.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * The identifier of the Post creator.
     * The value set may be {@code null}.
     */
    public Author setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The Post author's avatar.
     * The value returned may be {@code null}.
     */
    public Image getImage() {
      return image;
    }

    /**
     * The Post author's avatar.
     * The value set may be {@code null}.
     */
    public Author setImage(Image image) {
      this.image = image;
      return this;
    }

    /**
     * The URL of the Post creator's Profile page.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * The URL of the Post creator's Profile page.
     * The value set may be {@code null}.
     */
    public Author setUrl(String url) {
      this.url = url;
      return this;
    }

    /**
     * The Post author's avatar.
     */
    public static final class Image extends GenericJson {

      /**
       * The Post author's avatar URL.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String url;

      /**
       * The Post author's avatar URL.
       * The value returned may be {@code null}.
       */
      public String getUrl() {
        return url;
      }

      /**
       * The Post author's avatar URL.
       * The value set may be {@code null}.
       */
      public Image setUrl(String url) {
        this.url = url;
        return this;
      }

    }
  }

  /**
   * Data about the blog containing this Post.
   */
  public static final class Blog extends GenericJson {

    /**
     * The identifier of the Blog that contains this Post.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The identifier of the Blog that contains this Post.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * The identifier of the Blog that contains this Post.
     * The value set may be {@code null}.
     */
    public Blog setId(String id) {
      this.id = id;
      return this;
    }

  }

  /**
   * The location for geotagged posts.
   */
  public static final class Location extends GenericJson {

    /**
     * Location's latitude.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Double lat;

    /**
     * Location's longitude.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Double lng;

    /**
     * Location name.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String name;

    /**
     * Location's viewport span. Can be used when rendering a map preview.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String span;

    /**
     * Location's latitude.
     * The value returned may be {@code null}.
     */
    public Double getLat() {
      return lat;
    }

    /**
     * Location's latitude.
     * The value set may be {@code null}.
     */
    public Location setLat(Double lat) {
      this.lat = lat;
      return this;
    }

    /**
     * Location's longitude.
     * The value returned may be {@code null}.
     */
    public Double getLng() {
      return lng;
    }

    /**
     * Location's longitude.
     * The value set may be {@code null}.
     */
    public Location setLng(Double lng) {
      this.lng = lng;
      return this;
    }

    /**
     * Location name.
     * The value returned may be {@code null}.
     */
    public String getName() {
      return name;
    }

    /**
     * Location name.
     * The value set may be {@code null}.
     */
    public Location setName(String name) {
      this.name = name;
      return this;
    }

    /**
     * Location's viewport span. Can be used when rendering a map preview.
     * The value returned may be {@code null}.
     */
    public String getSpan() {
      return span;
    }

    /**
     * Location's viewport span. Can be used when rendering a map preview.
     * The value set may be {@code null}.
     */
    public Location setSpan(String span) {
      this.span = span;
      return this;
    }

  }

  /**
   * The container of comments on this Post.
   */
  public static final class Replies extends GenericJson {

    /**
     * The List of Comments for this Post.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Comment> items;

    static {
      // hack to force ProGuard to consider Comment used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Comment.class);
    }

    /**
     * The URL of the comments on this post.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String selfLink;

    /**
     * The count of comments on this post.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long totalItems;

    /**
     * The List of Comments for this Post.
     * The value returned may be {@code null}.
     */
    public java.util.List<Comment> getItems() {
      return items;
    }

    /**
     * The List of Comments for this Post.
     * The value set may be {@code null}.
     */
    public Replies setItems(java.util.List<Comment> items) {
      this.items = items;
      return this;
    }

    /**
     * The URL of the comments on this post.
     * The value returned may be {@code null}.
     */
    public String getSelfLink() {
      return selfLink;
    }

    /**
     * The URL of the comments on this post.
     * The value set may be {@code null}.
     */
    public Replies setSelfLink(String selfLink) {
      this.selfLink = selfLink;
      return this;
    }

    /**
     * The count of comments on this post.
     * The value returned may be {@code null}.
     */
    public Long getTotalItems() {
      return totalItems;
    }

    /**
     * The count of comments on this post.
     * The value set may be {@code null}.
     */
    public Replies setTotalItems(Long totalItems) {
      this.totalItems = totalItems;
      return this;
    }

  }

}
